@@ -6,6 +6,7 @@ from sqlalchemy import exists, desc, text, and_
 from sqlalchemy.inspection import inspect
 from scrapeanything.database.models import Model
 import os
+import traceback
 
 from scrapeanything.utils.types import Types
 from scrapeanything.utils.utils import Utils
@@ -34,22 +35,25 @@ class Repository:
         Arguments: <data> - collection or single model
         Returns: last id inserted or updated
         '''
-        data = entity
+        try:
+            data = entity
 
-        #region entity
-        model_from_database = self.load(entity=data)
-        model = self.update(entity_from_database=model_from_database, entity=data)
+            model_from_database = self.load(entity=data)
+            model = self.update(entity_from_database=model_from_database, entity=data)
 
-        if model not in self.session:
-            self.session.merge(model)
-        # else:
-        #     self.session.merge(model)
+            if model not in self.session:
+                self.session.merge(model)
+            # else:
+            #     self.session.merge(model)
 
-        # self.session.commit()
+            # self.session.commit()
+
+            entity_type = type(model)
+            Log.trace('Saved entity {0} with id {1}', entity_type, model.id)
+        except Exception as e:
+            Log.error(f'An error ocurred: {e}')
+            Log.error(traceback.format_exc()))
 
-        entity_type = type(model)
-        Log.trace('Saved entity {0} with id {1}', entity_type, model.id)
-        #endregion entity
 
     def update(self, entity_from_database: any, entity: any) -> any:
         '''
